Test coverage report: auction.context_processors

# auction.context_processors: 6 total statements, 0.0% covered

Generated: Mon 2013-04-29 18:13 CST

Source file: /home/slam/workspace/django-auction/auction/context_processors.py

Stats: 0 executed, 5 missed, 1 excluded, 1 ignored

1. `from auction.utils.generic import get_or_create_bidbasket`
2. ``
3. `def bidbasket(request):`
4. `user = request.user`
5. `bidbasket = get_or_create_bidbasket(request)`
6. `result = {'bidbasket':bidbasket}`
7. `return result`